function [f,Y] = dif_exp_pred(x, X, TI, Wtr, numrpar)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dif_exp_pred contains the objective function to be minimized during the
% ODE based modeling. It is called by 'InvalidationMain' main function.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% get predicted values by numerical integration
[~,Y] = ode45(@(t,y)simplemodel(t,y,x), TI , x(numrpar+1:end) );
WeighDifmat = Wtr .* (X-Y);

% objective function to be minimized
f = WeighDifmat(WeighDifmat~=0);
end

%%% ODE system defining the kinetic model
function [dydt] = simplemodel(~,y,x)
r1 = x(1);                          % r1 = kin;
r2 = (x(2) * y(1)) / (x(3) + y(1)); % r2 = vmax1*S / Km1 + S;
r3 = (x(4) * y(2)) / (x(5) + y(2)); % r3 = vmax2*P1 / Km2 + P1;
r4 = (x(6) * y(3)) / (x(7) + y(3)); % r4 = vmax3*P2 / Km3 + P2;
r5 = (x(8) * y(4)) / (x(9) + y(4)); % r5 = vmax4*P3 / Km4 + P3;
r6 = x(10) * y(5);                  % r6 = kout*P4;

dydt(1,:) = r1 - r2; %S
dydt(2,:) = r2 - r3; %P1
dydt(3,:) = r3 - r4; %P2
dydt(4,:) = r4 - r5; %P2
dydt(5,:) = r5 - r6; %P3
end